#include "mainwindow.h"

#define VISIBILITY_BUG 1

MainWindow::MainWindow(QWidget *parent)
   : QMainWindow(parent), cam_(NULL)
{
   QTabWidget *tab = new QTabWidget;

   QPushButton *button1 = new QPushButton("Start Cam");
   connect(button1, SIGNAL(pressed()), this, SLOT(start()));

   tab->addTab(button1, "Cam");

   QPushButton *button2 = new QPushButton("Quit");
   connect(button2, SIGNAL(pressed()), this, SLOT(close()));

   tab->addTab(button2, "Other");

   setCentralWidget(tab);
}

MainWindow::~MainWindow()
{
   stop();
}

void MainWindow::start()
{
   if (!cam_)
   {
      cam_ = new QQuickWidget();

      connect(cam_, SIGNAL(statusChanged(QQuickWidget::Status)),
              this, SLOT(camStatusChanged(QQuickWidget::Status)));

      cam_->setSource(QUrl("qrc:///declarative-camera.qml"));
      cam_->setResizeMode(QQuickWidget::SizeRootObjectToView);
   }
}

void MainWindow::camStatusChanged(QQuickWidget::Status status)
{
   if (status == QQuickWidget::Ready)
   {
      connect(cam_->engine(), SIGNAL(quit()),
              this, SLOT(stop()));

      cam_->show();
      cam_->raise();

#ifdef VISIBILITY_BUG
      hide();
#endif
   }
}

void MainWindow::stop()
{
   if (cam_)
   {
      cam_->hide();
      cam_->lower();

#ifdef VISIBILITY_BUG
      show();
#endif

      cam_->deleteLater(); // note that one cannot use delete
      cam_ = NULL;
   }
}
